@@ -4,7 +4,7 @@ AtteanX::Serializer::SPARQLHTML - SPARQL Results HTML Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::SPARQLHTML version 0.034
+This document describes AtteanX::Serializer::SPARQLHTML version 0.035
 
 =head1 SYNOPSIS
 
@@ -35,13 +35,13 @@ This document describes AtteanX::Serializer::SPARQLHTML version 0.034
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::SPARQLHTML 0.034 {
+package AtteanX::Serializer::SPARQLHTML 0.035 {
 	use Moo;
 	use Types::Standard qw(Str Bool ArrayRef);
 	use Encode qw(encode);
 	use Scalar::Util qw(blessed);
 	use Attean::ListIterator;
-	use List::MoreUtils qw(any);
+	use List::Util qw(any);
 	use namespace::clean;
 
 	has 'full_document' => (is => 'rw', isa => Bool, default => 1);
